@@ -285,6 +285,9 @@ class DocParser:
 
     def _parse_attachment(self, attachment):
         parsed_attachment = list(self._parse(attachment["content"], attachment["filename"], save_to_file=False)) #this could be a list of multiple files
+        
+        extension = Extension.predict(attachment["content"], file_name=attachment["filename"])
+        is_archive = extension in Extension.ARCHIVE_EXTENSIONS
 
         extracted_attachments = []
         for ix, sub_file in enumerate(parsed_attachment):
@@ -292,17 +295,21 @@ class DocParser:
             sub_attachment = attachment.copy()
             sub_attachment["content"] = sub_file["text"]
 
+            #infer filename from teporal path since the original was extension
+            if(is_archive):
+                sub_attachment["filename"] = os.path.split(sub_file["properties"]["path"])[1]
+
             #also add metadata of the file to the dictionary
             sub_attachment[META_FIELD] = sub_file[META_FIELD]
 
             #also add potential error messages
             if("errors" in sub_file):
-                sub_attachment["errors"] = sub_file["errors"] 
+                sub_attachment["errors"] = sub_file["errors"]
 
             # in case the attachment was an archive and contained multiple files,
             # add index number to attachment id to show it 
             if(len(parsed_attachment) > 1):
-               sub_attachment["attachment_id"] = sub_attachment["attachment_id"] + "_" + str(ix+1)
+               sub_attachment["id"] = sub_attachment["id"] + "_" + str(ix+1)
 
             extracted_attachments.append(sub_attachment)
             
