@@ -13,7 +13,7 @@ logging.basicConfig(
 
 class MLPProcessor:
 
-    def __init__(self, mlp, use_celery=False, app=None, worker_name="worker.taskman.mlp"):
+    def __init__(self, mlp, use_celery=False, app=None, worker_name="worker.taskman.mlp", queue="mlp_queue"):
         self.mlp = mlp
         self.processing_functions = {
             "Normal": self._apply_mlp,
@@ -21,6 +21,8 @@ class MLPProcessor:
         }
         self.celery = use_celery
         self.worker_name = worker_name
+        self.queue = queue
+
         if use_celery and app:
             self.app = app
 
@@ -48,7 +50,7 @@ class MLPProcessor:
 
     def _apply_mlp_celery(self, document: dict, field: str, analyzers: list):
         try:
-            result = self.app.send_task(self.worker_name, args=[[document], [field], analyzers])
+            result = self.app.send_task(self.worker_name, queue=self.queue, args=[[document], [field], analyzers])
 
             while not result.ready():
                 time.sleep(0.1)
